==> deepin-font-manager_6.5.3.tar.xz: BUILD/translations/deepin-font-manager_ug.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ug">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>بارلىق خەت شەكلى</translation>
    </message>
    <message>
        <source>System</source>
        <translation>سىستېما خەت شەكلى</translation>
    </message>
    <message>
        <source>User</source>
        <translation>ئىشلەتكۈچى خەت شەكلى</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ساقلىۋالغانلىرىم</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>ئاكتىپلانغان</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>خەنزۇچە خەت شەكلى</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>تەڭ كەڭلىك خەت شەكلى</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 بولسا بىر خەت شەكلى   گۇرۇپپىسى، ئۇنى ئۆچۈرسىڭىز ئۇنىڭغا تەۋە بارلىق خەت شەكلى  لار ئۆچۈرۈلۈپ كېتىشى مۇمكىن</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ئۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 بولسا بىر خەت شەكلى   گۇرۇپپىسى، ئۇنى قوزغاتسىڭىز ئۇنىڭغا تەۋە بارلىق خەت شەكلى  لار قوزغىلىشى مۇمكىن</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 بولسا بىر خەت شەكلى   گۇرۇپپىسى، ئۇنى چەكلىۋەتسىڭىز ئۇنىڭغا تەۋە بارلىق خەت شەكلى  لار چەكلىنىشى مۇمكىن</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>خەت شەكلىنى قوزغىتىش</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>خەت شەكلىنى چەكلەش</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>تاللانغان خەت شەكلى   گۇرۇپپىسىغا قوللىنىش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>ھۆججەت بۇزۇلغان</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>ئوخشاش نەشرى قاچىلانغان</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>سىستېما خەت شەكلى</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 دانە خەت شەكلى قاچىلانغان</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 دانە خەت شەكلى قاچىلانغان</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation type="unfinished">ھۆججەت بۇزۇلغان</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>بۇ خەت شەكلىنى چۈرۈلگەندىن كېيىن، باشقا پىروگراممىلاردا  ئىشلەتكىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>بۇ خەت شەكلى ئۆچۈرۈلگەندىن كېيىن باشقا پىروگراممىلاردا ئىشلىتىلمەيدۇ</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>باشقا %1 دانە سىستېما خەت شەكلىنى ئۆچۈرگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>ئۆچۈرگىلى بولمايدىغان ئىشلىتىلىۋاتقان خەت شەكىللىرى: %1</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>ئۆچۈرگىلى بولمايدىغان باشقا %1 دانە سىستېما خەت شەكلىنى ۋە ئىشلىتىلىۋاتقان خەت شەكلى: %2</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 دانە خەت شەكلىنى راستلا ئۆچۈرەمسىز؟</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ئۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>خەت شەكلىنى ئۆچۈرۈۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>خەت شەكلىنى دەلىللەش</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>قاچىلىغىلى بولىدىغان خەت شەكلى يوق</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation type="unfinished">چېكىنىش</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation type="unfinished">داۋاملاشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>ئاساسىي ئۇچۇر</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>نۇسخا</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>تۈر</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>نەشرى</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>تەسۋىر</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>تولۇق نامى</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps نامى</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>تاۋار ماركىسى</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation>نەشىر ھوقۇقى</translation>
    </message>
    <message>
        <source>License Description</source>
        <translation>ئىجازەتنامىنى تەسۋىرلەش </translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>خەت شەكلى   باشقۇرغۇچ</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>خەت باشقۇرغۇچ ئابونتلارنىڭ خەت نۇسخىسىنى ئورنىتىشى ۋە باشقۇرۇشىغا ياردەم بېرىدۇ.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>خەت شەكلى يۈكلىنىۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>بۇ خەت شەكلى ئۈستەليۈزىگە چىقىرىلدى</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 دانە خەت شەكلى ئۈستەليۈزىگە چىقىرىلدى</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>نىشان دىسكىنىڭ سىغىمى يېتىشمىگەچكە، 1 دانە ھۆججەتنى چىقىرالمىدى</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>نىشان دىسكىنىڭ سىغىمى يېتىشمىگەچكە، %1 دانە ھۆججەتنى چىقىرالمىدى</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>خەت شەكلى قوشۇش</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>خەت شەكلىنى قوزغىتىش</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>خەت شەكلىنى چەكلەش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ساقلىۋېلىش</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>ئۇچۇر</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>خەت شەكلىنى چىقىرىش</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>چەكلەندى</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>خەت شەكلى چەكلەندى</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 ئىشلىتىلىۋاتىدۇ، چەكلىگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>سىستېما خەت شەكلى ۋە ئىشلىتىۋاتقان خەت شەكلىنى چەكلىگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>سىستېما خەت شەكلىنى چەكلىگىلى بولمايدۇ</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>خەت شەكلى قاچىلاش</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>دەلىللەۋاتىدۇ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>ھۆججەت بۇزۇلغان</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>قاچىلاندى</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>قاچىلانمىغان</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>خەت شەكلى قاچىلاش</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>خەت شەكلى يوق</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>ياردەم</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>تېزلەتمە كۇنۇپكا كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>ئالدىنقى بەت</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>كېيىنكى بەت</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>خەت شەكلى قوشۇش</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ساقلىۋېلىش</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>خەت شەكلى ئۇچۇرى</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>تېكىست كىرگۈزۈپ كۆرۈپ بېقىڭ</translation>
    </message>
</context>
</TS>

==> deepin-font-manager_6.5.15.tar.xz: BUILD/translations/deepin-font-manager_ug.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="ug">
<context>
    <name>Category</name>
    <message>
        <source>All Fonts</source>
        <translation>بارلىق خەت شەكلى</translation>
    </message>
    <message>
        <source>System</source>
        <translation>سىستېما خەت شەكلى</translation>
    </message>
    <message>
        <source>User</source>
        <translation>ئىشلەتكۈچى خەت شەكلى</translation>
    </message>
    <message>
        <source>Favorites</source>
        <translation>ساقلىۋالغانلىرىم</translation>
    </message>
    <message>
        <source>Active</source>
        <translation>ئاكتىپلانغان</translation>
    </message>
    <message>
        <source>Chinese</source>
        <translation>خەنزۇچە خەت شەكلى</translation>
    </message>
    <message>
        <source>Monospaced</source>
        <translation>تەڭ كەڭلىك خەت شەكلى</translation>
    </message>
</context>
<context>
    <name>DFDeleteDialog</name>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>DFDeleteTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be deleted</source>
        <translation>%1 بولسا بىر خەت شەكلى   گۇرۇپپىسى، ئۇنى ئۆچۈرسىڭىز ئۇنىڭغا تەۋە بارلىق خەت شەكلى  لار ئۆچۈرۈلۈپ كېتىشى مۇمكىن</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ئۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>DFDisableTTCDialog</name>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be enabled</source>
        <translation>%1 بولسا بىر خەت شەكلى   گۇرۇپپىسى، ئۇنى قوزغاتسىڭىز ئۇنىڭغا تەۋە بارلىق خەت شەكلى  لار قوزغىلىشى مۇمكىن</translation>
    </message>
    <message>
        <source>%1 is a font family, if you proceed, all fonts in it will be disabled</source>
        <translation>%1 بولسا بىر خەت شەكلى   گۇرۇپپىسى، ئۇنى چەكلىۋەتسىڭىز ئۇنىڭغا تەۋە بارلىق خەت شەكلى  لار چەكلىنىشى مۇمكىن</translation>
    </message>
    <message>
        <source>Enable</source>
        <comment>button</comment>
        <translation>خەت شەكلىنى قوزغىتىش</translation>
    </message>
    <message>
        <source>Disable</source>
        <comment>button</comment>
        <translation>خەت شەكلىنى چەكلەش</translation>
    </message>
</context>
<context>
    <name>DFHandleTTCDialog</name>
    <message>
        <source>Apply to all selected font families</source>
        <translation>تاللانغان خەت شەكلى   گۇرۇپپىسىغا قوللىنىش</translation>
    </message>
    <message>
        <source>Cancel</source>
        <translation>بىكار قىلىش</translation>
    </message>
</context>
<context>
    <name>DFInstallErrorDialog</name>
    <message>
        <source>Broken file</source>
        <translation>ھۆججەت بۇزۇلغان</translation>
    </message>
    <message>
        <source>Same version installed</source>
        <translation>ئوخشاش نەشرى قاچىلانغان</translation>
    </message>
    <message>
        <source>System Font</source>
        <translation>سىستېما خەت شەكلى</translation>
    </message>
</context>
<context>
    <name>DFontMgrMainWindow</name>
    <message>
        <source>Ctrl+Shift+/</source>
        <translation>Ctrl+Shift+/</translation>
    </message>
    <message>
        <source>PgUp</source>
        <translation>PgUp</translation>
    </message>
    <message>
        <source>PgDown</source>
        <translation>PgDown</translation>
    </message>
    <message>
        <source>Ctrl+Alt+F</source>
        <translation>Ctrl+Alt+F</translation>
    </message>
    <message>
        <source>Ctrl+F</source>
        <translation>Ctrl+F</translation>
    </message>
    <message>
        <source>Ctrl+O</source>
        <translation>Ctrl+O</translation>
    </message>
    <message>
        <source>Ctrl+=</source>
        <translation>Ctrl+=</translation>
    </message>
    <message>
        <source>Ctrl+-</source>
        <translation>Ctrl+-</translation>
    </message>
    <message>
        <source>Ctrl+0</source>
        <translation>Ctrl+0</translation>
    </message>
    <message>
        <source>%1 font installed</source>
        <translation>%1 دانە خەت شەكلى قاچىلانغان</translation>
    </message>
    <message>
        <source>%1 fonts installed</source>
        <translation>%1 دانە خەت شەكلى قاچىلانغان</translation>
    </message>
    <message>
        <source>Alt+M</source>
        <translation>Alt+M</translation>
    </message>
    <message>
        <source>CTRL+I</source>
        <translation>CTRL+I</translation>
    </message>
    <message>
        <source>Failed to install %1 font. There is not enough disk space.</source>
        <translation>نىشان دىسكىنىڭ سىغىمى يېتىشمىگەچكە، %1 ھۆججەت قاچىلانمىدى</translation>
    </message>
    <message>
        <source>Failed to install %1 fonts. There is not enough disk space.</source>
        <translation>نىشان دىسكىنىڭ سىغىمى يېتىشمىگەچكە، %1 ھۆججەت قاچىلانمىدى</translation>
    </message>
    <message>
        <source>Fonts</source>
        <translation>خەت شەكلى</translation>
    </message>
</context>
<context>
    <name>DFontWidget</name>
    <message>
        <source>Broken file</source>
        <translation>ھۆججەت بۇزۇلغان</translation>
    </message>
</context>
<context>
    <name>DeleteConfirmDailog</name>
    <message>
        <source>This font will not be available to applications</source>
        <translation>بۇ خەت شەكلىنى چۈرۈلگەندىن كېيىن، باشقا پىروگراممىلاردا  ئىشلەتكىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>These fonts will not be available to applications</source>
        <translation>بۇ خەت شەكلى ئۆچۈرۈلگەندىن كېيىن باشقا پىروگراممىلاردا ئىشلىتىلمەيدۇ</translation>
    </message>
    <message>
        <source>The other %1 system fonts cannot be deleted</source>
        <translation>باشقا %1 دانە سىستېما خەت شەكلىنى ئۆچۈرگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>The font &quot;%1&quot; in use cannot be deleted</source>
        <translation>ئۆچۈرگىلى بولمايدىغان ئىشلىتىلىۋاتقان خەت شەكىللىرى: %1</translation>
    </message>
    <message>
        <source>The other %1 system fonts and the font &quot;%2&quot; in use cannot be deleted</source>
        <translation>ئۆچۈرگىلى بولمايدىغان باشقا %1 دانە سىستېما خەت شەكلىنى ۋە ئىشلىتىلىۋاتقان خەت شەكلى: %2</translation>
    </message>
    <message>
        <source>Are you sure you want to delete %1 font(s)?</source>
        <translation>%1 دانە خەت شەكلىنى راستلا ئۆچۈرەمسىز؟</translation>
    </message>
    <message>
        <source>Delete</source>
        <comment>button</comment>
        <translation>ئۆچۈرۈش</translation>
    </message>
</context>
<context>
    <name>Dfuninstalldialog</name>
    <message>
        <source>Deleting fonts, please wait...</source>
        <translation>خەت شەكلىنى ئۆچۈرۈۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
</context>
<context>
    <name>ExceptionWindow</name>
    <message>
        <source>Font Verification</source>
        <translation>خەت شەكلىنى دەلىللەش</translation>
    </message>
    <message>
        <source>No fonts to be installed</source>
        <translation>قاچىلىغىلى بولىدىغان خەت شەكلى يوق</translation>
    </message>
    <message>
        <source>Exit</source>
        <translation>چېكىنىش</translation>
    </message>
    <message>
        <source>Continue</source>
        <translation>داۋاملاشتۇرۇش</translation>
    </message>
</context>
<context>
    <name>Font</name>
    <message>
        <source>Don&apos;t let your dreams be dreams</source>
        <translation>ئارزۇ ئۈچۈن بارلىققا كەلگەن، مەسئۇلىيەت ئۈچۈن يېتىلگەن</translation>
    </message>
</context>
<context>
    <name>FontDetailDailog</name>
    <message>
        <source>Basic info</source>
        <translation>ئاساسىي ئۇچۇر</translation>
    </message>
    <message>
        <source>Style</source>
        <translation>نۇسخا</translation>
    </message>
    <message>
        <source>Type</source>
        <translation>تۈر</translation>
    </message>
    <message>
        <source>Version</source>
        <translation>نەشرى</translation>
    </message>
    <message>
        <source>Description</source>
        <translation>تەسۋىر</translation>
    </message>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
    <message>
        <source>Full name</source>
        <translation>تولۇق نامى</translation>
    </message>
    <message>
        <source>Ps name</source>
        <translation>Ps نامى</translation>
    </message>
    <message>
        <source>Trademark</source>
        <translation>تاۋار ماركىسى</translation>
    </message>
    <message>
        <source>Copyright</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>License Description</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Font Manager</source>
        <translation>خەت شەكلى   باشقۇرغۇچ</translation>
    </message>
    <message>
        <source>Font Manager helps users install and manage fonts.</source>
        <translation>خەت باشقۇرغۇچ ئابونتلارنىڭ خەت نۇسخىسىنى ئورنىتىشى ۋە باشقۇرۇشىغا ياردەم بېرىدۇ.</translation>
    </message>
    <message>
        <source>Loading fonts, please wait...</source>
        <translation>خەت شەكلى يۈكلىنىۋاتىدۇ، سەل ساقلاڭ...</translation>
    </message>
    <message>
        <source>The font exported to your desktop</source>
        <translation>بۇ خەت شەكلى ئۈستەليۈزىگە چىقىرىلدى</translation>
    </message>
    <message>
        <source>%1 fonts exported to your desktop</source>
        <translation>%1 دانە خەت شەكلى ئۈستەليۈزىگە چىقىرىلدى</translation>
    </message>
    <message>
        <source>Failed to export 1 font. There is not enough disk space.</source>
        <translation>نىشان دىسكىنىڭ سىغىمى يېتىشمىگەچكە، 1 ھۆججەتنى چىقىرالمىدى</translation>
    </message>
    <message>
        <source>Failed to export %1 fonts. There is not enough disk space.</source>
        <translation>نىشان دىسكىنىڭ سىغىمى يېتىشمىگەچكە، %1 ھۆججەتنى چىقىرالمىدى</translation>
    </message>
</context>
<context>
    <name>Menu</name>
    <message>
        <source>Add font</source>
        <translation>خەت شەكلى قوشۇش</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>خەت شەكلىنى قوزغىتىش</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>خەت شەكلىنى چەكلەش</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ساقلىۋېلىش</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>ئۇچۇر</translation>
    </message>
    <message>
        <source>Display in file manager</source>
        <translation>ھۆججەت باشقۇرغۇچتا كۆرسىتىش</translation>
    </message>
    <message>
        <source>Export</source>
        <translation>خەت شەكلىنى چىقىرىش</translation>
    </message>
</context>
<context>
    <name>MessageManager</name>
    <message>
        <source>deactivated</source>
        <translation>چەكلەندى</translation>
    </message>
    <message>
        <source>The fonts have been deactivated</source>
        <translation>خەت شەكلى چەكلەندى</translation>
    </message>
    <message>
        <source>%1 is in use, so you cannot disable it</source>
        <translation>%1 ئىشلىتىلىۋاتىدۇ، چەكلىگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>You cannot disable system fonts and the fonts in use</source>
        <translation>سىستېما خەت شەكلى ۋە ئىشلىتىۋاتقان خەت شەكلىنى چەكلىگىلى بولمايدۇ</translation>
    </message>
    <message>
        <source>You cannot disable system fonts</source>
        <translation>سىستېما خەت شەكلىنى چەكلىگىلى بولمايدۇ</translation>
    </message>
</context>
<context>
    <name>NormalInstallWindow</name>
    <message>
        <source>Install Font</source>
        <translation>خەت شەكلى قاچىلاش</translation>
    </message>
    <message>
        <source>Verifying...</source>
        <translation>دەلىللەۋاتىدۇ...</translation>
    </message>
</context>
<context>
    <name>QuickInstallWindow</name>
    <message>
        <source>Unknown</source>
        <translation>نامەلۇم</translation>
    </message>
    <message>
        <source>Broken file</source>
        <translation>ھۆججەت بۇزۇلغان</translation>
    </message>
    <message>
        <source>Installed</source>
        <translation>قاچىلاندى</translation>
    </message>
    <message>
        <source>Not Installed</source>
        <translation>قاچىلانمىغان</translation>
    </message>
    <message>
        <source>Install Font</source>
        <translation>خەت شەكلى قاچىلاش</translation>
    </message>
</context>
<context>
    <name>SearchBar</name>
    <message>
        <source>Search</source>
        <translation>ئىزدەش</translation>
    </message>
    <message>
        <source>No search results</source>
        <translation>ئىزدەش نەتىجىسى يوق</translation>
    </message>
    <message>
        <source>No fonts</source>
        <translation>خەت شەكلى يوق</translation>
    </message>
</context>
<context>
    <name>Shortcut</name>
    <message>
        <source>Help</source>
        <translation>ياردەم</translation>
    </message>
    <message>
        <source>Display shortcuts</source>
        <translation>تېزلەتمە كۇنۇپكا كۆرۈنسۇن</translation>
    </message>
    <message>
        <source>Page up</source>
        <translation>ئالدىنقى بەت</translation>
    </message>
    <message>
        <source>Page down</source>
        <translation>كېيىنكى بەت</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>ئۆچۈرۈش</translation>
    </message>
    <message>
        <source>Add font</source>
        <translation>خەت شەكلى قوشۇش</translation>
    </message>
    <message>
        <source>Favorite</source>
        <translation>ساقلىۋېلىش</translation>
    </message>
    <message>
        <source>Unfavorite</source>
        <translation>بىكار قىلىش</translation>
    </message>
    <message>
        <source>Font info</source>
        <translation>خەت شەكلى ئۇچۇرى</translation>
    </message>
</context>
<context>
    <name>StateBar</name>
    <message>
        <source>Input preview text</source>
        <translation>تېكىست كىرگۈزۈپ كۆرۈپ بېقىڭ</translation>
    </message>
</context>
</TS>
